@@ -68,6 +68,11 @@ class Backend:
             self.time_factor_threshold = params['timeFactorThreshold']
             self.time_factor_synapse = params['timeFactorSynapse']
             self.output_spike_connectivity = params['outConnSpike']
+            self.theta_leak = params['thetaLeak']
+            self.theta_increment = params['thetaIncrement']
+            self.theta_floor = params['thetaFloor']
+            self.V_reset = params['vReset']
+            self.g_increment = params['gIncrement']
         if self.delay:
             self.spike_delays = params['spikeDelays']
             self.spike_rows = params['spikeRows']
@@ -159,8 +164,7 @@ class SNS_Numpy(Backend):
             self.V = self.V_last + self.time_factor_membrane * (
                         -self.g_m * (self.V_last - self.V_rest) + self.i_b + i_syn + i_app)  # Update membrane potential
         if self.spiking:
-            self.theta = self.theta_last + self.time_factor_threshold * (
-                        -self.theta_last + self.theta_0 + self.m * (self.V_last - self.V_rest))  # Update the firing thresholds
+            self.theta = self.theta_last + self.time_factor_threshold * (self.theta_leak*(self.theta_0-self.theta_last) + self.m * (self.V_last - self.V_rest))  # Update the firing thresholds
             self.spikes = np.sign(np.minimum(0, self.theta - self.V))  # Compute which neurons have spiked
 
             # New stuff with delay
@@ -171,12 +175,11 @@ class SNS_Numpy(Backend):
                 self.delayed_spikes[self.spike_rows, self.spike_cols] = self.spike_buffer[
                     self.buffer_steps, self.buffer_nrns]
 
-                self.g_spike = np.maximum(self.g_spike, (
-                    -self.delayed_spikes) * self.g_max_spike)  # Update the conductance of connections which spiked
+                self.g_spike += np.minimum((-self.delayed_spikes*self.g_increment), (-self.delayed_spikes)*(self.g_max_spike-self.g_spike))  # Update the conductance of connections which spiked
             else:
-                self.g_spike = np.maximum(self.g_spike, (
-                    -self.spikes) * self.g_max_spike)  # Update the conductance of connections which spiked
-            self.V = ((self.V-self.V_rest) * (self.spikes + 1))+self.V_rest  # Reset the membrane voltages of neurons which spiked
+                self.g_spike += np.minimum((-self.spikes*self.g_increment), (-self.spikes)*(self.g_max_spike-self.g_spike))  # Update the conductance of connections which spiked
+            self.V = ((self.V-self.V_reset) * (self.spikes + 1))+self.V_reset  # Reset the membrane voltages of neurons which spiked
+            self.theta = np.maximum(self.theta_increment, self.theta_floor-self.theta)*(-self.spikes) + self.theta
         self.outputs = np.matmul(self.output_voltage_connectivity, self.V)
         if self.spiking:
             self.outputs += np.matmul(self.output_spike_connectivity, -self.spikes)
@@ -240,7 +243,10 @@ class SNS_Torch(Backend):
         else:
             self.V = self.V_last + self.time_factor_membrane * (-self.g_m * (self.V_last - self.V_rest) + self.i_b + i_syn + i_app)  # Update membrane potential
         if self.spiking:
-            self.theta = self.theta_last + self.time_factor_threshold * (-self.theta_last + self.theta_0 + self.m * (self.V_last - self.V_rest))  # Update the firing thresholds
+            self.theta = self.theta_last + self.time_factor_threshold * (
+                        self.theta_leak * (self.theta_0 - self.theta_last) + self.m * (
+                            self.V_last - self.V_rest))  # Update the firing thresholds
+
             self.spikes = torch.sign(torch.clamp(self.theta - self.V,max=0))  # Compute which neurons have spiked
 
             # New stuff with delay
@@ -250,10 +256,11 @@ class SNS_Torch(Backend):
                 # Update a matrix with all of the appropriately delayed spike values
                 self.delayed_spikes[self.spike_rows, self.spike_cols] = self.spike_buffer[self.buffer_steps, self.buffer_nrns]
 
-                self.g_spike = torch.maximum(self.g_spike, (-self.delayed_spikes) * self.g_max_spike)  # Update the conductance of connections which spiked
+                self.g_spike = self.g_spike + torch.minimum((-self.delayed_spikes*self.g_increment), (-self.delayed_spikes)*(self.g_max_spike-self.g_spike))  # Update the conductance of connections which spiked
             else:
-                self.g_spike = torch.maximum(self.g_spike, (-self.spikes) * self.g_max_spike)  # Update the conductance of connections which spiked
-            self.V = ((self.V - self.V_rest) * (self.spikes + 1)) + self.V_rest  # Reset the membrane voltages of neurons which spiked
+                self.g_spike = self.g_spike + torch.minimum((-self.spikes*self.g_increment), (-self.spikes)*(self.g_max_spike-self.g_spike))  # Update the conductance of connections which spiked
+            self.V = ((self.V - self.V_reset) * (self.spikes + 1)) + self.V_reset  # Reset the membrane voltages of neurons which spiked
+            self.theta = torch.maximum(self.theta_increment, self.theta_floor-self.theta)*(-self.spikes) + self.theta
         self.outputs = torch.matmul(self.output_voltage_connectivity, self.V)
         if self.spiking:
             self.outputs += torch.matmul(self.output_spike_connectivity, -self.spikes)
@@ -344,7 +351,7 @@ class SNS_Sparse(Backend):
                                                                                           :] + i_syn + i_app)  # Update membrane potential
         if self.spiking:
             self.theta = self.theta_last + self.time_factor_threshold * (
-                        -self.theta_last + self.theta_0 + (self.m.to_dense())[0,
+                        self.theta_leak*(-self.theta_last + self.theta_0) + (self.m.to_dense())[0,
                                                           :] * (self.V_last - self.V_rest))  # Update the firing thresholds
 
             self.spikes = torch.sign(torch.clamp(self.theta - self.V, max=0))  # Compute which neurons have spiked
@@ -363,13 +370,15 @@ class SNS_Sparse(Backend):
                     self.buffer_steps, self.buffer_nrns]
                 self.delayed_spikes = self.delayed_spikes.to_sparse()
 
-                self.g_spike = torch.maximum(self.g_spike.to_dense(), ((
-                                                                           -self.delayed_spikes) * self.g_max_spike).to_dense())  # Update the conductance of connections which spiked
+                self.g_spike = self.g_spike.to_dense() + torch.minimum(-self.delayed_spikes.to_dense()*self.g_increment, ((
+                                                                           -self.delayed_spikes.to_dense()) * (self.g_max_spike.to_dense()-self.g_spike.to_dense())).to_dense())  # Update the conductance of connections which spiked
             else:
-                self.g_spike = torch.maximum(self.g_spike.to_dense(), (
-                    -self.spikes.to_dense()) * self.g_max_spike.to_dense())  # Update the conductance of connections which spiked
+                self.g_spike = self.g_spike.to_dense() + torch.minimum(-self.spikes.to_dense()*self.g_increment, (
+                    -self.spikes.to_dense()) * (self.g_max_spike.to_dense()-self.g_spike.to_dense()))  # Update the conductance of connections which spiked
             self.g_spike = self.g_spike.to_sparse()
-            self.V = ((self.V - self.V_rest) * (self.spikes.to_dense() + 1)) + self.V_rest  # Reset the membrane voltages of neurons which spiked
+            self.V = ((self.V - self.V_reset) * (self.spikes.to_dense() + 1)) + self.V_reset  # Reset the membrane voltages of neurons which spiked
+            self.theta = torch.maximum(self.theta_increment, self.theta_floor - self.theta) * (
+                -self.spikes.to_dense()) + self.theta
         self.outputs = torch.matmul(self.output_voltage_connectivity, self.V)
         if self.spiking:
             self.outputs += torch.matmul(self.output_spike_connectivity, -self.spikes.to_dense())
@@ -427,6 +436,10 @@ class SNS_Iterative(Backend):
             self.tau_theta = params['tauTheta']
             self.time_factor_threshold = params['timeFactorThreshold']
             self.output_spike_connectivity = params['outConnSpike']
+            self.theta_leak = params['thetaLeak']
+            self.theta_increment = params['thetaIncrement']
+            self.theta_floor = params['thetaFloor']
+            self.V_reset = params['vReset']
         if self.delay:
             foo = 5
         if self.electrical:
@@ -472,6 +485,8 @@ class SNS_Iterative(Backend):
 
         for nrn in range(self.num_neurons):
             i_syn = 0
+            # if nrn == 8:
+            #     print(8)
             for syn in range(len(self.incoming_synapses[nrn])):
                 neuron_src = self.incoming_synapses[nrn][syn]
                 if neuron_src[1]:  # if spiking
@@ -514,8 +529,8 @@ class SNS_Iterative(Backend):
                     nrn] + i_gated)  # Update membrane potential
             if self.spiking:
                 # if self.theta_0[nrn] != sys.float_info.max:
-                self.theta[nrn] = self.theta_last[nrn] + self.time_factor_threshold[nrn] * (
-                            -self.theta_last[nrn] + self.theta_0[nrn] + self.m[nrn] * (self.V_last[nrn] - self.V_rest[nrn]))  # Update the firing thresholds
+                self.theta[nrn] = self.theta_last[nrn] + self.time_factor_threshold[nrn] * (self.theta_leak[nrn]*
+                            (-self.theta_last[nrn] + self.theta_0[nrn]) + self.m[nrn] * (self.V_last[nrn] - self.V_rest[nrn]))  # Update the firing thresholds
                 self.spikes[nrn] = np.sign(
                     np.minimum(0, self.theta[nrn] - self.V[nrn]))  # Compute which neurons have spiked
         if self.spiking:
@@ -525,11 +540,24 @@ class SNS_Iterative(Backend):
                     for syn in range(len(self.incoming_synapses[nrn])):
                         neuron_src = self.incoming_synapses[nrn][syn]
                         if neuron_src[1]:  # if spiking
-                            neuron_src[7] = np.roll(neuron_src[7], 1)  # Shift buffer entries down
-                            neuron_src[7][0] = self.spikes[neuron_src[0]]  # Replace row 0 with the current spike data
-                            neuron_src[5] = np.maximum(neuron_src[5], (-neuron_src[7][-1]) * neuron_src[
-                                3])  # Update the conductance of connections which spiked
-                self.V[nrn] = ((self.V[nrn] - self.V_rest[nrn]) * (self.spikes[nrn] + 1)) + self.V_rest[nrn]  # Reset the membrane voltages of neurons which spiked
+                            neuron_src[8] = np.roll(neuron_src[8], 1)  # Shift buffer entries down
+                            neuron_src[8][0] = self.spikes[neuron_src[0]]  # Replace row 0 with the current spike data
+                            neuron_src[5] += np.minimum((-neuron_src[8][-1] * neuron_src[7]),
+                                                       (-neuron_src[8][-1]) * (neuron_src[3] - neuron_src[5]))  # Update the conductance of connections which spiked
+                            # neuron_src[5] = np.maximum(neuron_src[5], (-neuron_src[8][-1]) * neuron_src[
+                            #     3])  # Update the conductance of connections which spiked
+                else:
+                    for syn in range(len(self.incoming_synapses[nrn])):
+                        neuron_src = self.incoming_synapses[nrn][syn]
+                        if neuron_src[1]:  # if spiking
+                            neuron_src[5] += np.minimum((-self.spikes[neuron_src[0]] * neuron_src[7]),
+                                                        (-self.spikes[neuron_src[0]]) * (neuron_src[3] - neuron_src[
+                                                            5]))  # Update the conductance of connections which spiked
+                            # neuron_src[5] = np.maximum(neuron_src[5], (-self.spikes[neuron_src[0]]) * neuron_src[
+                            #     3])  # Update the conductance of connections which spiked
+                self.V[nrn] = ((self.V[nrn] - self.V_reset[nrn]) * (self.spikes[nrn] + 1)) + self.V_reset[nrn]  # Reset the membrane voltages of neurons which spiked
+                self.theta[nrn] = np.maximum(self.theta_increment[nrn], self.theta_floor[nrn] - self.theta[nrn]) * (
+                    -self.spikes[nrn]) + self.theta[nrn]
         self.outputs = np.matmul(self.output_voltage_connectivity, self.V)
         if self.spiking:
             self.outputs += np.matmul(self.output_spike_connectivity, -self.spikes)
@@ -546,4 +574,4 @@ class SNS_Iterative(Backend):
             self.b_gate = np.copy(self.b_gate_0)
             self.b_gate_last = np.copy(self.b_gate_0)
             self.c_gate = np.copy(self.c_gate_0)
-            self.c_gate_last = np.copy(self.c_gate_0)
+            self.c_gate_last = np.copy(self.c_gate_0)
\ No newline at end of file
