@@ -491,6 +491,9 @@ class Network:
                     transmit_delay = __kernel_connections_2d__(self.populations[source]['shape'],
                                                                connection_type.params['transmissionDelay'])
                     self.connections[-1]['params']['transmissionDelay'] = transmit_delay
+                    g_increment = __kernel_connections_2d__(self.populations[source]['shape'],
+                                                               connection_type.params['conductance_increment'])
+                    self.connections[-1]['params']['conductanceIncrement'] = g_increment
                 else:
                     e_hi = __kernel_connections_2d__(self.populations[source]['shape'],
                                                      connection_type.params['e_hi'], fill_value=self.populations[source]['type'].params['resting_potential']+1)
@@ -514,6 +517,9 @@ class Network:
                     transmit_delay = __kernel_connections_1d__(self.populations[source]['number'],
                                                                connection_type.params['transmissionDelay'])
                     self.connections[-1]['params']['transmissionDelay'] = transmit_delay
+                    g_increment = __kernel_connections_1d__(self.populations[source]['number'],
+                                                               connection_type.params['conductanceIncrement'])
+                    self.connections[-1]['params']['transmissionDelay'] = g_increment
                 else:
                     e_hi = __kernel_connections_1d__(self.populations[source]['shape'],
                                                      connection_type.params['e_hi'], fill_value=self.populations[source]['type'].params['resting_potential']+1)
@@ -539,10 +545,10 @@ class Network:
 
         if connection_type.params['spiking']:
             self.params['spiking'] = True
-            if connection_type.params['transmissionDelay'] > 0:
+            if np.any(connection_type.params['transmissionDelay']) > 0:
                 self.params['delay'] = True
 
-    def add_network(self, network: 'Network', color: str = None) -> None:
+    def add_network(self, network: 'Network', color: str = None, suffix: str = None) -> None:
         """
         Add an existing topology of inputs, outputs, and populations to the network.
 
@@ -550,11 +556,15 @@ class Network:
         :type network:  sns_toolbox.design.networks.Network
         :param color:   Color to render nodes in the network, default is the original colors.
         :type color:    str, optional
+        :param suffix:  String to append to all the population/neuron names in the network.
+        :type suffix:   str, optional
         :return: None
         :rtype: N/A
         """
         if not isinstance(network, Network):
             raise TypeError('Network must be of type Network')
+        if suffix is None:
+            suffix = ''
 
         num_inputs = len(self.inputs)
         num_populations = len(self.populations)
@@ -563,12 +573,12 @@ class Network:
         if color is None:
             for population in network.populations:
                 self.add_population(neuron_type=population['type'], shape=population['shape'],
-                                    name=population['name'], color=population['color'])
+                                    name=population['name']+suffix, color=population['color'])
             for inp in network.inputs:
-                self.add_input(dest=inp['destination'] + num_populations, name=inp['name'], color=inp['color']
+                self.add_input(dest=inp['destination'] + num_populations, name=inp['name']+suffix, color=inp['color']
                                ,size=inp['size'])
             for out in network.outputs:
-                self.add_output(source=out['source'] + num_populations, name=out['name'], color=out['color'],
+                self.add_output(source=out['source'] + num_populations, name=out['name']+suffix, color=out['color'],
                                 spiking=out['spiking'])
             for connection in network.connections:
                 self.add_connection(connection_type=connection['type'], source=connection['source'] + num_populations,
@@ -579,12 +589,12 @@ class Network:
                 color = 'white'
             for population in network.populations:
                 self.add_population(neuron_type=population['type'], shape=population['shape'],
-                                    name=population['name'], color=color)
+                                    name=population['name']+suffix, color=color)
             for inp in network.inputs:
-                self.add_input(dest=inp['destination'] + num_populations, name=inp['name'], color=color
+                self.add_input(dest=inp['destination'] + num_populations, name=inp['name']+suffix, color=color
                                ,size=inp['size'])
             for out in network.outputs:
-                self.add_output(source=out['source'] + num_populations, name=out['name'], color=color,
+                self.add_output(source=out['source'] + num_populations, name=out['name']+suffix, color=color,
                                 spiking=out['spiking'])
             for connection in network.connections:
                 self.add_connection(connection_type=connection['type'], source=connection['source'] + num_populations,
@@ -624,7 +634,7 @@ class Network:
     #     self.graph.format = imgFormat
     #     self.graph.render(view=view,cleanup=True)
 
-    def compile(self, dt=0.01, backend='numpy', device='cpu', debug=False) -> Backend:
+    def compile(self, dt=0.01, backend='numpy', device='cpu', debug=False, return_params=False) -> Backend:
         if not isinstance(backend, str):
             raise TypeError(
                 'Backend selection must be a string. Options are \'numpy\', \'torch\', \'sparse\', or \'iterative\'')
@@ -633,7 +643,10 @@ class Network:
                 warnings.warn('Warning: Only CPU device is supported with SNS_Numpy. Switching to CPU')
             model = __compile_numpy__(self, dt=dt, debug=debug)
         elif backend == 'torch':
-            model = __compile_torch__(self, dt=dt, debug=debug, device=device)
+            if return_params:
+                model, params = __compile_torch__(self, dt=dt, debug=debug, device=device, return_params=return_params)
+            else:
+                model = __compile_torch__(self, dt=dt, debug=debug, device=device, return_params=return_params)
         elif backend == 'sparse':
             model = __compile_sparse__(self, dt=dt, debug=debug, device=device)
         elif backend == 'iterative':
@@ -643,7 +656,10 @@ class Network:
         else:
             raise ValueError(
                 backend + 'is not a valid simulation backend. Options are \'numpy\', \'torch\', \'sparse\', or \'iterative\'')
-        return model
+        if return_params:
+            return model, params
+        else:
+            return model
 
 """
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
